@@ -204,7 +204,7 @@ class GetPocketStream(RESTStream):
                 logger.info('Only getting basic info from data')
                 detail_type = 'basic'
             elif detail_type.lower() in ('complete', 'more'):
-                logger.info('Getting full data from data')
+                logger.info('Getting full info from data')
                 detail_type = 'complete'
             else:
                 raise ValueError('Invalid value for "detail_type" setting, should be "basic" or "complete"')
@@ -255,9 +255,16 @@ class GetPocketStream(RESTStream):
         # so if metric record count = 5000 the pipeline should always run again (STATE will guarantee that missing
         # records are fetched)
         r = response.json()
+
         if len(r['list']) == 0:
             logger.warning('No records found for current settings / state')
         else:
+            # drop all records marked as "to be deleted" (status=2)
+            delete_index = [k for k, v in r['list'].items() if r['list'][k].get('status') == '2']
+            logger.debug('Invalid records found to be deleted: {}'.format(delete_index))
+            for del_key in delete_index:
+                del r['list'][del_key]
+
             # sort by ascending update date
             # the api only allows to sort by time_added, not by time_updated (the replication_key)
             # update date is not always available (for very old articles, must be a "new" feature)
@@ -279,7 +286,8 @@ class GetPocketStream(RESTStream):
 
     def post_process(self, row: dict, context: Optional[dict]) -> dict:
         """
-        Convert date-time fields from unix to ISO time string
+        Convert fields into expected type according to schema
+        Replace missing values with default ones
         :param row:
         :param context:
         :return:
@@ -288,23 +296,59 @@ class GetPocketStream(RESTStream):
             row['time_updated'] = self.schema.get('properties').get('time_updated').get('default')
 
         for k, v in row.items():
-            formatted = format_timestamp(v, self.schema.get('properties').get(k))
-            row[k] = formatted
+            logger.debug('Processing {}'.format(k))
+            try:
+                formatted = format_type(v, self.schema.get('properties').get(k))
+            except:
+                # if this fails continue with original value
+                pass
+            else:
+                row[k] = formatted
             logging.debug('{} before: {}, after: {}'.format(k, v, formatted))
+
+        # if item not in row, use default value
+        properties = self.schema.get('properties')
+        for prop in properties:
+            if prop not in row:
+                logger.debug('Property {} not found in result'.format(prop))
+                logger.debug('Using default value: {}'.format(properties.get(prop).get('default')))
+                # if no default is defined, default value is None
+                try:
+                    row[prop] = properties.get(prop).get('default')
+                except:
+                    # if something fails, use None as default
+                    row[prop] = None
+
+        # make sure all elements are in the expected order
+        index_map = {v: i for i, v in enumerate(list(properties.keys()))}
+        row = dict(sorted(row.items(), key=lambda pair: index_map[pair[0]]))
+
         return row
 
 
-def format_timestamp(data, schema):
+def format_type(value, schema):
     """
 
-    :param data:
+    :param value:
     :param schema:
     :return:
     """
-    result = data
-    if data and isinstance(data, str) and data != '0' and schema.get('format') == 'date-time':
-        utc_dt = datetime.datetime.utcfromtimestamp(int(data)).replace(tzinfo=pytz.UTC)
-        result = utils.strftime(utc_dt)
+    result = value
+    if result and isinstance(result, str) and schema.get('format') == 'date-time':
+        # make sure date time fields are formatted as such
+        if result != '0':
+            utc_dt = datetime.datetime.utcfromtimestamp(int(result)).replace(tzinfo=pytz.UTC)
+            result = utils.strftime(utc_dt)
+        else:
+            # date not available, return None
+            result = None
+    if result and isinstance(result, str) and 'integer' in schema.get('type'):
+        # make sure integer fields are formatted as such
+        result = int(result)
+    if result and isinstance(result, str) and 'boolean' in schema.get('type'):
+        # make sure boolean fields are formatted as such
+        # string 0 is converted to True, so make sure we evaluate truthy here before
+        result = truthy(result)
     return result
 
 
