@@ -26,21 +26,7 @@ class ContentStream(GetPocketStream):
         th.Property("has_image", th.BooleanType),
         th.Property("has_video", th.BooleanType),
         th.Property("word_count", th.IntegerType),
-        th.Property("tags",
-                    th.ObjectType(
-                        th.Property("item_id", th.IntegerType),
-                        th.Property("tag", th.IntegerType)
-                    )),
-        th.Property("authors",
-                    th.ObjectType(
-                        th.Property("item_id", th.IntegerType),
-                        th.Property("author_id", th.IntegerType),
-                        th.Property("name", th.StringType),
-                        th.Property("url", th.StringType),
-                    )),
-        th.Property("images", th.ObjectType()),
-        th.Property("videos", th.ObjectType()),
-        th.Property("time_updated", th.DateTimeType, default='0'),
+        th.Property("time_updated", th.DateTimeType),
         th.Property("time_added", th.DateTimeType),
         th.Property("time_read", th.DateTimeType),
         th.Property("time_favorited", th.DateTimeType),
@@ -51,6 +37,18 @@ class ContentStream(GetPocketStream):
         th.Property("time_to_read", th.IntegerType),
         th.Property("amp_url", th.StringType),
         th.Property("top_image_url", th.StringType),
+        th.Property("tags",
+                    th.ObjectType(
+                        th.Property("item_id", th.IntegerType),
+                        th.Property("tag", th.StringType)
+                    )),
+        th.Property("authors",
+                    th.ObjectType(
+                        th.Property("item_id", th.IntegerType),
+                        th.Property("author_id", th.IntegerType),
+                        th.Property("name", th.StringType),
+                        th.Property("url", th.StringType),
+                    )),
         th.Property("domain_metadata",
                     th.ObjectType(
                         th.Property("greyscale_logo", th.StringType),
@@ -58,4 +56,9 @@ class ContentStream(GetPocketStream):
                         th.Property("name", th.StringType),
                                 )
                     ),
+        th.Property("image",
+                    th.ObjectType()),
+        th.Property("images",
+                    th.ObjectType()),
+        th.Property("videos", th.ObjectType()),
     ).to_dict()
